==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QMainWindow.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QMainWindow (
  QMainWindowValue (..),
  QMainWindowConstPtr (..),
  QMainWindowPtr (..),
  QMainWindowConst,
  QMainWindow,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  centralWidget,
  createPopupMenu,
  documentMode,
  iconSize,
  isAnimated,
  isDockNestingEnabled,
  menuBar,
  menuWidget,
  setAnimated,
  setCentralWidget,
  setDockNestingEnabled,
  setDocumentMode,
  setIconSize,
  setMenuBar,
  setMenuWidget,
  setStatusBar,
  setUnifiedTitleAndToolBarOnMac,
  statusBar,
  unifiedTitleAndToolBarOnMac,
  iconSizeChangedSignal,
  ) where

import qualified Graphics.UI.Qtah.Core.HSize as HSize
import Graphics.UI.Qtah.Generated.Widgets.QMainWindow
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQMainWindowConst
cast = toQMainWindow
downCastConst = downToQMainWindowConst
downCast = downToQMainWindow

iconSizeChangedSignal :: (QMainWindowPtr object) => QtahSignal.Signal object (HSize.HSize -> HoppyP.IO ())
iconSizeChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQSize_new fn'
    listenerQSize_connectListener listener' object' "2iconSizeChanged(QSize)"
  , QtahSignal.internalName = "QMainWindow::iconSizeChanged (ListenerQSize)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QMainWindow.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QMainWindow (
  QMainWindowValue (..),
  QMainWindowConstPtr (..),
  QMainWindowPtr (..),
  QMainWindowConst,
  QMainWindow,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  addDockWidget,
  addDockWidgetWithOrientation,
  addToolBar,
  addToolBarWithTitle,
  centralWidget,
  corner,
  createPopupMenu,
  dockWidgetArea,
  documentMode,
  emitIconSizeChanged,
  iconSize,
  isAnimated,
  isDockNestingEnabled,
  menuBar,
  menuWidget,
  removeDockWidget,
  restoreDockWidget,
  restoreState,
  restoreStateWithVersion,
  saveState,
  saveStateWithVersion,
  setAnimated,
  setCentralWidget,
  setCorner,
  setDockNestingEnabled,
  setDocumentMode,
  setIconSize,
  setMenuBar,
  setMenuWidget,
  setStatusBar,
  setUnifiedTitleAndToolBarOnMac,
  splitDockWidget,
  statusBar,
  unifiedTitleAndToolBarOnMac,
  iconSizeChangedSignal,
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import qualified Graphics.UI.Qtah.Core.HSize as HSize
import Graphics.UI.Qtah.Generated.Widgets.QMainWindow
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQMainWindowConst
cast = toQMainWindow
downCastConst = downToQMainWindowConst
downCast = downToQMainWindow

iconSizeChangedSignal :: (QMainWindowPtr object) => QtahSignal.Signal object (HSize.HSize -> HoppyP.IO ())
iconSizeChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQSize_new object' "2iconSizeChanged(QSize)" fn'
    valid' <- listenerQSize_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QMainWindow::iconSizeChanged (ListenerQSize)"
  }
